@@ -9,7 +9,7 @@ java -jar ./openapi-generator-cli.jar generate \
 --git-user-id=vrchatapi \
 --git-repo-id=vrchatapi-rust \
 -o . \
--i https://vrchatapi.github.io/specification/openapi.yaml \
+-i https://raw.githubusercontent.com/vrchatapi/specification/gh-pages/openapi.yaml \
 --http-user-agent="vrchatapi-rust"
 #--global-property debugOperations=true
 
